@@ -1,6 +1,6 @@
 package WWW::Google::APIDiscovery::API;
 
-$WWW::Google::APIDiscovery::API::VERSION = '0.11';
+$WWW::Google::APIDiscovery::API::VERSION = '0.12';
 
 use 5.006;
 use Moo;
@@ -12,7 +12,7 @@ WWW::Google::APIDiscovery::API - Placeholder for supported APIS.
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
@@ -41,6 +41,10 @@ has description => (is => 'ro', required => 1);
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-Google-APIDiscovery>
+
 =head1 BUGS
 
 Please  report  any  bugs or feature requests to C<bug-www-google-apidiscovery at
