@@ -1,6 +1,6 @@
 package WWW::Google::APIDiscovery::API::MetaData;
 
-$WWW::Google::APIDiscovery::API::MetaData::VERSION = '0.11';
+$WWW::Google::APIDiscovery::API::MetaData::VERSION = '0.12';
 
 use 5.006;
 use Moo;
@@ -12,7 +12,7 @@ WWW::Google::APIDiscovery::API::MetaData - Placeholder for supported APIS Meta D
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
@@ -87,6 +87,10 @@ has resources         => (is => 'ro');
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-Google-APIDiscovery>
+
 =head1 BUGS
 
 Please  report  any  bugs or feature requests to C<bug-www-google-apidiscovery at
